**Purpose**: Homebox is the inventory and organization system built for the Home User! With a focus on simplicity and ease of use, Homebox is the perfect solution for your home inventory, organization, and management needs.

[Reference Documentation](https://hay-kot.github.io/homebox/quick-start/)


## Docker Configuration
```jsx title="docker-compose.yml"
version: "3.4"

services:
  homebox:
    image: ghcr.io/hay-kot/homebox:latest
    container_name: homebox
    restart: always
    environment:
    - HBOX_LOG_LEVEL=info
    - HBOX_LOG_FORMAT=text
    - HBOX_WEB_MAX_UPLOAD_SIZE=10
    volumes:
      - /srv/containers/homebox:/data/
    ports:
      - 3100:7745
    networks:
        docker_network:
          ipv4_address: 192.168.5.25
networks:
  docker_network:
    external: true
```

```jsx title=".env"
N/A
```

## Traefik Reverse Proxy Configuration
If the container does not run on the same host as Traefik, you will need to manually add configuration to Traefik's dynamic config file, outlined below.
``` yaml
http:
  routers:
    homebox:
      entryPoints:
        - websecure
      tls:
        certResolver: letsencrypt
      http2:
      service: homebox
      rule: Host(`box.bunny-lab.io`)
      middlewares:
        - "auth-bunny-lab-io"  # Referencing the Keycloak Server
  services:
    homebox:
      loadBalancer:
        servers:
          - url: http://192.168.5.25:3100
        passHostHeader: true
```